@@ -5,21 +5,19 @@ import inspect
 import logging
 import numbers
 import os
-from typing import Any, Awaitable, Callable, Dict, Optional, Sequence, TypeVar, Union, cast, overload
+from typing import Any, Callable, Dict, Optional, Sequence, Union, cast, overload
 
 from ..shared import constants
 from ..shared.functions import resolve_env_var_choice, resolve_truthy_env_var_choice
 from ..shared.lazy_import import LazyLoader
+from ..shared.types import AnyCallableT
 from .base import BaseProvider, BaseSegment
 
 is_cold_start = True
 logger = logging.getLogger(__name__)
 
 aws_xray_sdk = LazyLoader(constants.XRAY_SDK_MODULE, globals(), constants.XRAY_SDK_MODULE)
-aws_xray_sdk.core = LazyLoader(constants.XRAY_SDK_CORE_MODULE, globals(), constants.XRAY_SDK_CORE_MODULE)
-
-AnyCallableT = TypeVar("AnyCallableT", bound=Callable[..., Any])  # noqa: VNE001
-AnyAwaitableT = TypeVar("AnyAwaitableT", bound=Awaitable)
+aws_xray_sdk.core = LazyLoader(constants.XRAY_SDK_CORE_MODULE, globals(), constants.XRAY_SDK_CORE_MODULE)  # type: ignore # noqa: E501
 
 
 class Tracer:
@@ -335,7 +333,7 @@ class Tracer:
     # see #465
     @overload
     def capture_method(self, method: "AnyCallableT") -> "AnyCallableT":
-        ...
+        ...  # pragma: no cover
 
     @overload
     def capture_method(
@@ -344,7 +342,7 @@ class Tracer:
         capture_response: Optional[bool] = None,
         capture_error: Optional[bool] = None,
     ) -> Callable[["AnyCallableT"], "AnyCallableT"]:
-        ...
+        ...  # pragma: no cover
 
     def capture_method(
         self,
@@ -719,16 +717,15 @@ class Tracer:
         Union[bool, str]
         """
         logger.debug("Verifying whether Tracing has been disabled")
-        is_lambda_sam_cli = os.getenv(constants.SAM_LOCAL_ENV)
-        is_chalice_cli = os.getenv(constants.CHALICE_LOCAL_ENV)
+        is_lambda_env = os.getenv(constants.LAMBDA_TASK_ROOT_ENV)
         is_disabled = resolve_truthy_env_var_choice(env=os.getenv(constants.TRACER_DISABLED_ENV, "false"))
 
         if is_disabled:
             logger.debug("Tracing has been disabled via env var POWERTOOLS_TRACE_DISABLED")
             return is_disabled
 
-        if is_lambda_sam_cli or is_chalice_cli:
-            logger.debug("Running under SAM CLI env or not in Lambda env; disabling Tracing")
+        if not is_lambda_env:
+            logger.debug("Running outside Lambda env; disabling Tracing")
             return True
 
         return False
