@@ -12,7 +12,7 @@ from botocore.config import Config
 
 from ...shared import constants
 from ...shared.functions import resolve_env_var_choice
-from .base import DEFAULT_PROVIDERS, BaseProvider
+from .base import DEFAULT_MAX_AGE_SECS, DEFAULT_PROVIDERS, BaseProvider
 
 CLIENT_ID = str(uuid4())
 
@@ -29,6 +29,8 @@ class AppConfigProvider(BaseProvider):
         Application of the configuration to pass during client initialization
     config: botocore.config.Config, optional
         Botocore configuration to pass during client initialization
+    boto3_session : boto3.session.Session, optional
+            Boto3 session to use for AWS API communication
 
     Example
     -------
@@ -60,13 +62,20 @@ class AppConfigProvider(BaseProvider):
 
     client: Any = None
 
-    def __init__(self, environment: str, application: Optional[str] = None, config: Optional[Config] = None):
+    def __init__(
+        self,
+        environment: str,
+        application: Optional[str] = None,
+        config: Optional[Config] = None,
+        boto3_session: Optional[boto3.session.Session] = None,
+    ):
         """
         Initialize the App Config client
         """
 
         config = config or Config()
-        self.client = boto3.client("appconfig", config=config)
+        session = boto3_session or boto3.session.Session()
+        self.client = session.client("appconfig", config=config)
         self.application = resolve_env_var_choice(
             choice=application, env=os.getenv(constants.SERVICE_NAME_ENV, "service_undefined")
         )
@@ -110,6 +119,7 @@ def get_app_config(
     application: Optional[str] = None,
     transform: Optional[str] = None,
     force_fetch: bool = False,
+    max_age: int = DEFAULT_MAX_AGE_SECS,
     **sdk_options
 ) -> Union[str, list, dict, bytes]:
     """
@@ -127,6 +137,8 @@ def get_app_config(
         Transforms the content from a JSON object ('json') or base64 binary string ('binary')
     force_fetch: bool, optional
         Force update even before a cached item has expired, defaults to False
+    max_age: int
+        Maximum age of the cached value
     sdk_options: dict, optional
         Dictionary of options that will be passed to the Parameter Store get_parameter API call
 
@@ -165,4 +177,6 @@ def get_app_config(
 
     sdk_options["ClientId"] = CLIENT_ID
 
-    return DEFAULT_PROVIDERS["appconfig"].get(name, transform=transform, force_fetch=force_fetch, **sdk_options)
+    return DEFAULT_PROVIDERS["appconfig"].get(
+        name, max_age=max_age, transform=transform, force_fetch=force_fetch, **sdk_options
+    )
