@@ -68,6 +68,13 @@ class APIGatewayEventRequestContext(BaseModel):
     routeKey: Optional[str]
     operationName: Optional[str]
 
+    @root_validator(allow_reuse=True)
+    def check_message_id(cls, values):
+        message_id, event_type = values.get("messageId"), values.get("eventType")
+        if message_id is not None and event_type != "MESSAGE":
+            raise TypeError("messageId is available only when the `eventType` is `MESSAGE`")
+        return values
+
 
 class APIGatewayProxyEventModel(BaseModel):
     version: Optional[str]
@@ -82,11 +89,4 @@ class APIGatewayProxyEventModel(BaseModel):
     pathParameters: Optional[Dict[str, str]]
     stageVariables: Optional[Dict[str, str]]
     isBase64Encoded: bool
-    body: str
-
-    @root_validator()
-    def check_message_id(cls, values):
-        message_id, event_type = values.get("messageId"), values.get("eventType")
-        if message_id is not None and event_type != "MESSAGE":
-            raise TypeError("messageId is available only when the `eventType` is `MESSAGE`")
-        return values
+    body: Optional[str]
